==> react-ranger-0.4.0.tgz: package/pkg/views/itemList.js <==
/** @jsx React.DOM */
'use strict';

var _ = require('lodash');
var React = require('react');

var File = require('./file');
var Directory = require('./directory');

var FileModel = require('../models/file');
var DirectoryModel = require('../models/directory');
var ItemListModel = require('../models/itemList');

var ItemList = React.createClass({displayName: 'ItemList',

  propTypes: {
    store: React.PropTypes.any.isRequired,
    contents: React.PropTypes.instanceOf(ItemListModel).isRequired,
    active: React.PropTypes.oneOfType([
      React.PropTypes.instanceOf(DirectoryModel),
      React.PropTypes.instanceOf(FileModel),
      React.PropTypes.bool,
    ]).isRequired,
  },

  componentDidUpdate: function() {
    if (! this.refs.active) { return; }
    var active = this.refs.active.getDOMNode();
    var node = this.getDOMNode();

    node.scrollTop = active.offsetTop - (node.offsetHeight / 2);

  },

  render: function () {
    var contents = '';

    if (this.props.contents && this.props.contents.length) {
      contents = this.props.contents.map(function (item, i) {
        var isActive = (item === this.props.active);

        var options = {
          key: i,
          item: item,
          active: isActive,
          store: this.props.store
        };

        if (isActive) {
          options.ref = 'active';
        }

        if (item instanceof DirectoryModel) {
          return new Directory(options);
        } else {
          return new File(options);
        }
      }, this);
    }

    return (
      /* jshint ignore: start */
      React.DOM.div({className: "item-list"}, contents)
      /* jshint ignore: end */
    );
  }

});

module.exports = ItemList;

==> react-ranger-0.5.2.tgz: package/pkg/views/itemList.js <==
/** @jsx React.DOM */
'use strict';

var _ = require('lodash');
var React = require('react');

var File = require('./file');
var Directory = require('./directory');

var FileModel = require('../models/file');
var DirectoryModel = require('../models/directory');
var ItemListModel = require('../models/itemList');

var ItemList = React.createClass({displayName: 'ItemList',

  propTypes: {
    store: React.PropTypes.any.isRequired,
    contents: React.PropTypes.instanceOf(ItemListModel).isRequired,
    active: React.PropTypes.oneOfType([
      React.PropTypes.instanceOf(DirectoryModel),
      React.PropTypes.instanceOf(FileModel),
      React.PropTypes.bool,
    ]).isRequired,
  },

  componentDidUpdate: function() {
    if (! this.refs.active) { return; }
    var item = this.refs.active.getDOMNode();
    var container = this.getDOMNode();

    var itemOffsetTop = item.offsetTop;
    var containerScrollTop = container.scrollTop;

    if (itemOffsetTop < containerScrollTop) {
      container.scrollTop = itemOffsetTop;
      return;
    }

    var itemOffsetHeight = item.offsetHeight;
    var containerOffsetHeight = container.offsetHeight;

    if (itemOffsetTop + itemOffsetHeight > containerScrollTop + containerOffsetHeight) {
      container.scrollTop = itemOffsetTop - containerOffsetHeight + itemOffsetHeight;
    }
  },

  render: function () {
    var contents = '';

    if (this.props.contents && this.props.contents.length) {
      contents = this.props.contents.map(function (item, i) {
        var isActive = (item === this.props.active);

        var options = {
          key: i,
          item: item,
          active: isActive,
          store: this.props.store
        };

        if (isActive) {
          options.ref = 'active';
        }

        if (item instanceof DirectoryModel) {
          return new Directory(options);
        } else {
          return new File(options);
        }
      }, this);
    }

    return (
      /* jshint ignore: start */
      React.DOM.div({className: "item-list"}, contents)
      /* jshint ignore: end */
    );
  }

});

module.exports = ItemList;
